# Prof.Li's Python Tools
## 道法自然
## **pip install -U shnu-llq-tools**
**sample code as follows:**
###### `from llq.util.data import fakeData
print(fakeData.gen(40))

### 'from llq.util.devices import GPU'

![hah](https://pic.pimg.tw/beigeetemple/1509175446-2818694733_n.jpg)